package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````)"````````!``````````$"A````
M`````````$``.``(`$``%@`5``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````:`````````!H``````````0`````````!````
M!0```````````````````````````````````&R0````````;)``````````
M``$```````$````&````@)L```````"`FP$``````(";`0``````^`0`````
M``!0%0```````````0```````@````8```"0FP```````)";`0``````D)L!
M``````#@`0```````.`!````````"`````````!0Y71D!````%R*````````
M7(H```````!<B@```````/0`````````]``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0```"`FP```````(";`0``````@)L!``````"`!```````
M`(`$`````````0`````````O;&EB+VQD+6UU<VPM86%R8V@V-"YS;RXQ````
M`````!$```!.````!`````@````A$!``!<`$@"@`$`6`AD"$@B$`!`D`!(F(
M@!A!N@0""$X```!/````4P```%@```!9````8````&$```!B`````````&0`
M``!E`````````&8```!G````:@```````````````:\TZ&I_FGSJT^\.SMY'
M+6_%WQ\NQ9NVN(WQ#M1DU'QV5#R4(?_D#MEQ6!SZH6Q@PN4_++(!BV]"^M>'
MXD?&`5COEWF[XY)\5<,\TF>OS&:(!W#30T75[#-BV^T5C"7,?ZF<F^"G`@IJ
M&IY0O]I7&Z/@^TD``````````````````````````````````````P`'`#@:
M`````````````````````````P`2``"@`0`````````````````,````$@``
M``````````````````````#:`0``$@`````````````````````````4````
M$0```````````````````````````@``$0````````````````````````!\
M`0``$@`````````````````````````;````$@``````````````````````
M``"Y`0``$@`````````````````````````C````$@``````````````````
M```````J````$@`````````````````````````-`@``$@``````````````
M``````````#%`0``$@`````````````````````````S````(```````````
M``````````````!!`P``(0````````````````````````!+````$@``````
M``````````````````!1````$@````````````````````````!8````$@``
M```````````````````````.`P``$@````````````````````````#_`@``
M$@````````````````````````"2`@``$@````````````````````````!?
M````$@`````````````````````````S`@``$@``````````````````````
M``!F````$@````````````````````````#'`@``$@``````````````````
M``````!M````$@````````````````````````!U````$@``````````````
M``````````"P`@``$@````````````````````````!]````$@``````````
M``````````````"#````$@````````````````````````",````(```````
M``````````````````#X`@``$@````````````````````````"H````$@``
M``````````````````````"M````$@`````````````````````````>`@``
M$0````````````````````````#.`@``$@````````````````````````!@
M`@``$@````````````````````````"T````$@``````````````````````
M``!2`@``$@````````````````````````!E`P``$@``````````````````
M``````!``P``$0````````````````````````"$`@``$@``````````````
M```````````M`P``$@````````````````````````!"`P``$0``````````
M``````````````"[````$@`````````````````````````E`P``$@``````
M``````````````````#$````$0````````````````````````"*`0``$@``
M``````````````````````#6````(@````````````````````````#E````
M(`````````````````````````#[````$@````````````````````````#P
M`@``$@````````````````````````!P`@``$@``````````````````````
M`````0``$@`````````````````````````&`0``(```````````````````
M``````"[`@``$@`````````````````````````@`0``$@``````````````
M``````````"J`0``$@`````````````````````````E`0``$@``````````
M``````````````"@`@``$@````````````````````````"9`0``$@``````
M```````````````````K`0``$@`````````````````````````\`0``$@``
M```````````````````````N`@``$@````````````````````````!^````
M$@`````````````````````````_`@``$@````````````````````````!Y
M`@``$@`````````````````````````>`P``$@``````````````````````
M``!"`0``$@`````````````````````````6`P``$@``````````````````
M``````!6`0``$@`````````````````````````I`@``$@``````````````
M``````````#H`0``$@````````````````````````!=`0``$@``````````
M``````````````!D`0``$@`````````````````````````_`P``(0``````
M``````````````````!U`0``$@````````````````````````!E!```$``3
M`-"P`0`````````````````Z`P``$@`)`%`>````````U`$```````#Z`0``
M$@`*``!-````````!`````````"G`P``$@`)`$`N````````W`4```````!U
M!```$@`)`&PW````````9`````````"$`P``$@`)`'0H````````!```````
M```9!```$@`'`#@:````````!`````````#*`P``$@`)`!PT````````4`,`
M```````?!```$``3`'B@`0````````````````!-!```$@`)`'@H````````
MT`$````````"!```$``3`'B@`0````````````````"5`P``$@`)`(PM````
M````M`````````"T`P``$@`)`+@F````````.`````````"\`P``$@`)`!0M
M````````6`````````#@`P``$@`)`/Q)````````<`$```````#U`P``$@`)
M`$@J````````(``````````.!```$``3`-"P`0````````````````!P!```
M$``3`-"P`0````````````````!*`P``$@`)`$`@````````*``````````M
M!```$@`)`&@J````````!`$```````#K`P``$0`2`'"@`0``````"```````
M``!&!```$``2`'B@`0`````````````````'!```$@`)`"0@````````````
M```````6!```$@`)`*!)````````7`````````!3`P``$@`)`&PM````````
M(`````````!N`P``$@`)`$0G````````,`$```````!:!```$@`)`&Q+````
M````E`$```````!D!```$``3`-"P`0`````````````````Y!```$@`)`&PK
M````````J`$`````````;&EB<&5R;"YS;P!O<&5N9&ER`'-T9&5R<@!R96%L
M;&]C`&%C8V5S<P!S;G!R:6YT9@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L
M<V5E:P!G971P:60`<W1R8VUP`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S=')N
M8VUP`&QS=&%T`&-L;W-E9&ER`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L
M90!O<&5N`'-T<G-T<@!S=')C:'(`<F5A9&QI;FL`7U]S=&%C:U]C:&M?9W5A
M<F0`7U]C>&%?9FEN86QI>F4`7U]R96=I<W1E<E]F<F%M95]I;F9O`&5X:70`
M8VQO<V4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!R96%D`')M9&ER`%]?
M97)R;F]?;&]C871I;VX`;6MD:7(`<'1H<F5A9%]G971S<&5C:69I8P!M96UC
M<'D`<W1R;&5N`%]?<W1A8VM?8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E
M<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T
M<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V
M7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%]F:6YI`%!,7V1O7W5N9'5M<`!0
M97)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?
M<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?
M9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R
M;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A
M9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!L:6)C+FUU<VPM86%R8V@V-"YS;RXQ
M`&9P<FEN=&8`<W1R9'5P`'!T:')E861?871F;W)K`')E861D:7(`<W!R:6YT
M9@!S=')T;VL`<W1R;F-P>0!?7VQI8F-?<W1A<G1?;6%I;@!?7U]E;G9I<F]N
M`%]S=&%R=%]C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C=7)R
M96YT7V5X96-?<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A<E]S971U<%]L:6)P
M871H`'!A<E]M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?8VQE86X`6%-?26YT
M97)N86QS7U!!4E]"3T]4`'-H85]U<&1A=&4`;7E?<&%R7W!L`'!A<E]B87-E
M;F%M90!?7V)S<U]S=&%R=`!?7V5N9%]?`'-H85]I;FET`%]?8G-S7W-T87)T
M7U\`<&%R7V1I<FYA;64`<&%R7VEN:71?96YV`%]E9&%T80!P87)?9FEN9'!R
M;V<`<VAA7V9I;F%L`%]?8G-S7V5N9%]?`%]E;F0`<&%R7V-L96%N=7``+W5S
M<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4``(";`0```````P0````````\
M(0```````(B;`0```````P0```````#4(````````("?`0```````P0`````
M``!0'@```````)B?`0```````P0`````````30```````+"?`0```````P0`
M```````X&@````````"@`0```````P0`````````H`$``````!"@`0``````
M`P0````````030```````!B@`0```````P0````````[30```````"B@`0``
M`````P0````````530```````#"@`0```````P0````````53@```````#B@
M`0```````P0````````@30```````$"@`0```````P0````````G3@``````
M`$B@`0```````P0````````H30```````%B@`0```````P0````````L30``
M`````&"@`0```````P0````````Q30```````'"@`0```````P0```````#)
M3P```````(B?`0```````00```4``````````````)"?`0```````00```8`
M`````````````*"?`0```````00```X``````````````*B?`0```````00`
M`!\``````````````+B?`0```````00``",``````````````,"?`0``````
M`00``"P``````````````,B?`0```````00``"\``````````````-"?`0``
M`````00``#$``````````````-B?`0```````00``#(``````````````."?
M`0```````00``#<``````````````.B?`0```````00``#P`````````````
M`/"?`0```````00``#T``````````````/B?`0```````00``$(`````````
M`````(B=`0```````@0```,``````````````)"=`0```````@0```0`````
M`````````)B=`0```````@0```<``````````````*"=`0```````@0```@`
M`````````````*B=`0```````@0```D``````````````+"=`0```````@0`
M``H``````````````+B=`0```````@0```L``````````````,"=`0``````
M`@0```P``````````````,B=`0```````@0```T``````````````-"=`0``
M`````@0```X``````````````-B=`0```````@0``!```````````````."=
M`0```````@0``!$``````````````.B=`0```````@0``!(`````````````
M`/"=`0```````@0``!,``````````````/B=`0```````@0``!0`````````
M``````">`0```````@0``!4```````````````B>`0```````@0``!8`````
M`````````!">`0```````@0``!<``````````````!B>`0```````@0``!@`
M`````````````"">`0```````@0``!D``````````````"B>`0```````@0`
M`!H``````````````#">`0```````@0``!L``````````````#B>`0``````
M`@0``!P``````````````$">`0```````@0``!T``````````````$B>`0``
M`````@0``!X``````````````%">`0```````@0``"```````````````%B>
M`0```````@0``"$``````````````&">`0```````@0``"(`````````````
M`&B>`0```````@0``"0``````````````'">`0```````@0``"4`````````
M`````'B>`0```````@0``"8``````````````(">`0```````@0``"<`````
M`````````(B>`0```````@0``"@``````````````)">`0```````@0``"H`
M`````````````)B>`0```````@0``"L``````````````*">`0```````@0`
M`"T``````````````*B>`0```````@0``"X``````````````+">`0``````
M`@0``#```````````````+B>`0```````@0``#$``````````````,">`0``
M`````@0``#(``````````````,B>`0```````@0``#,``````````````-">
M`0```````@0``#0``````````````-B>`0```````@0``#4`````````````
M`.">`0```````@0``#8``````````````.B>`0```````@0``#@`````````
M`````/">`0```````@0``#D``````````````/B>`0```````@0``#H`````
M``````````"?`0```````@0``#L```````````````B?`0```````@0``#X`
M`````````````!"?`0```````@0``#\``````````````!B?`0```````@0`
M`$```````````````""?`0```````@0``$$``````````````"B?`0``````
M`@0``$,``````````````#"?`0```````@0``$0``````````````#B?`0``
M`````@0``$4``````````````$"?`0```````@0``$8``````````````$B?
M`0```````@0``$<``````````````%"?`0```````@0``$@`````````````
M`%B?`0```````@0``$D``````````````&"?`0```````@0``$H`````````
M`````&B?`0```````@0``$L``````````````'"?`0```````@0``$T`````
M`````````/U[OZG]`P"1_7O!J,`#7]8``````````/![OZG0``"0$<)&^1`"
M-I$@`A_6'R`#U1\@`]4?(`/5T```D!'&1OD0(C:1(`(?UM```)`1RD;Y$$(V
MD2`"'];0``"0$<Y&^1!B-I$@`A_6T```D!'21OD0@C:1(`(?UM```)`1UD;Y
M$*(VD2`"'];0``"0$=I&^1#"-I$@`A_6T```D!'>1OD0XC:1(`(?UM```)`1
MXD;Y$`(WD2`"'];0``"0$>9&^1`B-Y$@`A_6T```D!'J1OD00C>1(`(?UM``
M`)`1[D;Y$&(WD2`"'];0``"0$?)&^1""-Y$@`A_6T```D!'V1OD0HC>1(`(?
MUM```)`1^D;Y$,(WD2`"'];0``"0$?Y&^1#B-Y$@`A_6T```D!$"1_D0`CB1
M(`(?UM```)`1!D?Y$"(XD2`"'];0``"0$0I'^1!".)$@`A_6T```D!$.1_D0
M8CB1(`(?UM```)`1$D?Y$((XD2`"'];0``"0$19'^1"B.)$@`A_6T```D!$:
M1_D0PCB1(`(?UM```)`1'D?Y$.(XD2`"'];0``"0$2)'^1`".9$@`A_6T```
MD!$F1_D0(CF1(`(?UM```)`1*D?Y$$(YD2`"'];0``"0$2Y'^1!B.9$@`A_6
MT```D!$R1_D0@CF1(`(?UM```)`1-D?Y$*(YD2`"'];0``"0$3I'^1#".9$@
M`A_6T```D!$^1_D0XCF1(`(?UM```)`10D?Y$`(ZD2`"'];0``"0$49'^1`B
M.I$@`A_6T```D!%*1_D00CJ1(`(?UM```)`13D?Y$&(ZD2`"'];0``"0$5)'
M^1"".I$@`A_6T```D!%61_D0HCJ1(`(?UM```)`16D?Y$,(ZD2`"'];0``"0
M$5Y'^1#B.I$@`A_6T```D!%B1_D0`CN1(`(?UM```)`19D?Y$"([D2`"'];0
M``"0$6I'^1!".Y$@`A_6T```D!%N1_D08CN1(`(?UM```)`1<D?Y$(([D2`"
M'];0``"0$79'^1"B.Y$@`A_6T```D!%Z1_D0PCN1(`(?UM```)`1?D?Y$.([
MD2`"'];0``"0$8)'^1`"/)$@`A_6T```D!&&1_D0(CR1(`(?UM```)`1BD?Y
M$$(\D2`"'];0``"0$8Y'^1!B/)$@`A_6T```D!&21_D0@CR1(`(?UM```)`1
MED?Y$*(\D2`"'];0``"0$9I'^1#"/)$@`A_6T```D!&>1_D0XCR1(`(?UM``
M`)`1HD?Y$`(]D2`"'];0``"0$:9'^1`B/9$@`A_6T```D!&J1_D00CV1(`(?
MUM```)`1KD?Y$&(]D2`"'];0``"0$;)'^1""/9$@`A_6T```D!&V1_D0HCV1
M(`(?UM```)`1ND?Y$,(]D2`"'];]>[NI_0,`D?-3`:G3``"PU```D/43`/GB
MAP.IXN,`D>$#`9'@3P"YX#,!D9'__Y?"``"0P```D$+\1_D`^$?YX0,"JB__
M_Y?```"0`,A'^0``0#F``0`U8O__EV+"`I%`#`#Y8```M2``@%*-__^7I/__
MEX#>1_D``$"YP?__EQ_$*#F4WD?Y@`)`N;W__Y<!:%(Y(0`?,@%H$CF``D"Y
MN/__EP%H4CDA```R`6@2.>!/0+D`%``1`'Q]DXG__Y?E(T#YXP,`JF'"`I'B
M3T"YY`"`DJ``0/E@``#Y````\``,/Y%@!`#YP```L",$`/D`.$#Y8`@`^0``
M`/``&#^18`P`^8``@%(@!`"Y``"`T@`$`)%?``!K3`4`5$`0`!%UP@*10@P`
M$0$``+"`S""+(<`;D00`@-)_:"#XH`Y`^1#__Y?T`P`J@```-:`.0/E<__^7
M]`,`*G7"`I&@#D#Y-/__EP```/``/#>1FP``E&`!`+6@"D#YH```M0```/``
M$#:1E0``E*`*`/E@P@*1``A`^4```+3A!0"4<\("D6`.0/F#__^7IO[_E^`#
M%"KS4T&I]1-`^?U[Q:C``U_6`1``$:9X8/B!S"&+9F@A^-#__Q<=`(#2'@"`
MTN`#`)&A``#P(4`ND1_L?)(!```4X@,`JJ0``/"C``#PH```\(3,1_D%`(#2
M8]A'^0#`1_E!A$#X"___%\```)``X`&1P0``D"'@`9$_``#KP```5*$``/`A
MU$?Y80``M/`#`:H``A_6P`-?UL```)``X`&1P0``D"'@`9$A``#+0@"`TB'\
M0Y,A#,*:P0``M*(``/!"\$?Y8@``M/`#`JH``A_6P`-?UL```)`!X$$YX0(`
M-?U[OJG]`P"1\PL`^?,#`*J@``#P`.A'^8```+3```"0``!`^?/^_Y?8__^7
MH```\`#01_F```"T(```T`!`+9%X_O^7(`"`4F#B`3GS"T#Y_7O"J,`#7];`
M`U_6H```\`#L1_D@`0"T_7N_J<$``)`@``#0_0,`D2$``I$`0"V1X/[_E_U[
MP:C,__\7_7N\J?T#`)'S4P&I]5L"J?=C`ZD`!0"T]@,`JJ```/``X$?Y%P!`
M^7<$`+3X`P&JX@,6JD``0#D?]`!Q!!A`>B$#`%1"`!9+]0,7JE-\0).T`D#Y
MU`$`M.(#$ZKA`Q:JX`,4JGS^_Y<@`@`U@&IS.!_T`''!`0!4M0(7RW,&`)&4
M`A.+M?Y#DQ4#`+G@`Q2J\U-!J?5;0JGW8T.I_7O$J,`#7]9"!`"1X___%[4B
M`)'H__\7%`"`TO7__Q?]>[VI_0,`D?,+`/FS``#P<^9'^6$"0/GA%P#Y`0"`
MTN&3`)'(__^7XA=`^6$"0/E!``'*00``M/3^_Y?S"T#Y_7O#J,`#7];]>[RI
MH0``\/T#`)'S4P&I]`,`JO,#`:H@Y$?Y]5L"J;4``/`"`$#YXA\`^0(`@-+V
MTP"1M>)'^>$#%JK@`Q2JK___E^```+5AYD?YXA]`^2``0/E```#*0`$`M-G^
M_Y>@`D#YXC>`N0(,`HM`!$#Y0```^2#^_[1"(`"1_/__%_-30:GU6T*I_7O$
MJ,`#7];]>[JI_0,`D?5;`JFV``#P]0,`JL#F1_GS4P&I\P,!JO=C`ZGY:P2I
M`0!`^>$O`/D!`(#28`)`.1_T`'%!``!4<P8`D>`#$ZJV_O^7X5,!D?<#`*K@
M`Q6JA?__E_0#`*H``@"TK_[_EQ\`%^MC!@!4`0"`TF!J83B`:B$X(00`D:#_
M_S4``(!2UN9'^>(O0/G!`D#Y00`!RH$)`+2E_O^7M```\(#B1_D:`$#Y``"`
MTD(C`-'X`P`J``0`D4%X8/BA__^UP0``D``+`!$BL$"Y`'Q]DR(!`#3A`P"J
MX`,:JK#]_Y>!XD?Y(```^:`!`+4``(`2Y?__%R(`@%(BL`"YZ/W_E_D#`*I`
M__^T`G]]D^$#&JKG_?^7@.)'^1D``/F4XD?Y`']`DP`$`)&!`D#Y/W@@^/A7
M`+GA`Q6J(`!`.1_T`'$$&$!ZP0,`5+0``/#X5X"Y(0`5R^`*`)&4XD?Y&/-]
MTP#`(8N9`D#YS?W_ER!K./C@^_^TX5>`N8`"0/D!>&'XX@,!JJ`60#@A!`"1
M(/`?.&```#0?]`!Q0?__5*`'@%)````Y``"`TF)J8#@B:"`X``0`D:+__S6R
M__\7(00`D=[__Q?S4T&I]5M"J?=C0ZGY:T2I_7O&J,`#7];]>[*I_0,`D?5;
M`JFV``#PP>9'^?-3`:GW8P.I^6L$J2(`0/GB;P#Y`@"`TH`"`+0!`$`Y]`,`
MJB$"`#15_?^7]P,`JL`!`+08``#0&0``T!CO-)$YZS21^F,!D>`#%ZJ`_?^7
M\P,`JF`!`+7@`Q>JJ/W_E^`#%*H"_O^7UN9'^>%O0/G``D#Y(```RF`%`+0P
M_O^7<TX`D>$#&*K@`Q.J;/W_E\#]_S3A`QFJX`,3JFC]_Y=`_?\TX`,4JB'^
M_Y?U`P"JX`,3JA[^_Y>@`@`+``@`$0!\0)-Z_?^7XP,3JN(#%*KU`P"J`0``
MT"'T-)$$_O^7X0,:JN`#%:KQ_?^7'P0`,4`!`%3@:T"Y``P4$A\00''!``!4
MX`,5JKG__Y?@`Q6JX_W_E\W__Q?@`Q6J8/W_E_O__Q?S4T&I]5M"J?=C0ZGY
M:T2I_7O.J,`#7];]>[6I_0,`D?-3`:FS``#P]`,`JF'F1_DB`$#YXE<`^0(`
M@-+AHP"18OW_ET`"`#7A.T"Y`@"44B$,%!(_$$!Q)!!">L$``%3@`Q2J00"`
M4A#]_Y<?``!QX!>?&G/F1_GB5T#Y80)`^4$``<J!``"TY/W_EP``@%+Y__\7
M\U-!J?U[RZC``U_6_7N_J:```/#]`P"1`-Q'^0``0+G!_?^7_7O!J*(``/`C
M``#0`0``T$+T1_ECN"B1(0PUD;']_Q?]>[ZI_0,`D?,+`/FS``#P<]Y'^6`"
M0+FR_?^7Z___EV`"0+FO_?^7\PM`^00``-#]>\*HA`@_D>,#!*H%`(!2`@``
ML`$``-!"<!"1(7PUD>C\_Q<,"H32_V,LR_U[`*G]`P"1]5L"J;8``/#`YD?Y
M\U,!J?3C`)$!`$#YX2<0^0$`@-+K_/^7XP,`*@0``-#@`Q2JA-`UD0(``-`A
M`(+20N`UD<_\_Y<?!``Q`0$`5`,`@-+`YD?YX2=0^0``0/D@``#*(`4`M)[]
M_Y<!?$"3/P1`\4D``%0`?2#4H/[_-P`(@M+S8R"+X0,3JN`#%*H"`(+2+_W_
ME_0#`*J@_?\W``0`$0!\0)/J_/^7XP,`J@#]_[25?D"3'P`3ZX(``%0``!6+
M?P(`ZX/]_U1_`!/KB0``5&`"%8M_``#KX_S_5"``@E*?`@!KC/S_5.`#`ZKB
M`Q6JX0,3JFK]_Y?C`P"J'V@U.-3__Q?@`P.J#`J$TOU[0*GS4T&I]5M"J?]C
M+(O``U_6M/__%PP>@M+_8RS+_7L`J?T#`)'U6P*IM0``\/-3`:GT`P"J\P,!
MJJ#F1_GW8P.I^6L$J?LK`/D!`$#YX7<(^0$`@-(```#0`!`VD5K^_Y?X`P"J
MX06`4N`#%*K@_/^78`$`M````-#A`Q2J`#0VD8?^_Y>UYD?YX7=(^:`"0/D@
M``#*0`D`M$W]_Y?@`Q2J1_W_EQ8``-#Y`P`JP6HVD>`#$ZH:``#0&P``T"C]
M_Y=:[S21\P,`JGMS-I'WHP.1,_W_M&`"0#D?``!Q<Q*:FE@!`+3A`Q.JX`,8
MJGC\_Y?````UP6HVD0``@-(8_?^7\P,`JO/__Q?@`Q.J+/W_EV'"((LA\%\X
M/[P`<2`"`%0A!P`1(```"Q_\/W%,^O]4Y0,4JN0#&ZKC`Q.JX`,7J@(``-`!
M`(+20K0YD4C\_Y<`!``1'P1`<:D``%0`?2#4``0`47_*(#CJ__\7X:,!D>`#
M%ZKR_/^7X/O_->![0+D`#!02'R!`<6'[_U3@`Q>J(0"`4C+\_Y?@^O\UX0,7
MJ@```-``-#:1/?[_E^`#%ZI[_/^7]`,`JK/__Q?@`Q2J#!Z"TOU[0*GS4T&I
M]5M"J?=C0ZGY:T2I^RM`^?]C+(O``U_6X0,`JB(`0#E"```UP`-?UB$$`)%?
MO`!Q`!"!FOK__Q?`!P"T_7N^J?T#`)'S"P#Y\P,`J@$`0#G!```U````T`#L
M-)'S"T#Y_7O"J%O\_Q?B_/^7`@0`T6("`HM_`@+K@@,`5$``0#D?O`!QH`(`
M5$$`0#G@`P*J0@0`T3^\`'%!`@!4X@,`JD($`-%_`@+K@@``5$``0#D?O`!Q
M8/__5$(`$\M`"`"1'P1`\2@#`%1"!`"17P1`\<D!`%0`?2#40@0`T>;__Q=_
M`@+K(_W_5'\"`NNA_?]48`)`.1^\`''@^O]4````T`!P-I'6__\7PP``D&-`
M`Y'A`Q.JX`,#JEK\_Y?S"T#Y_7O"J,`#7]8``(#2_/__%P```-``[#21R___
M%_U[N:G]`P"1\U,!J;,``/`4``#08.9'^?5;`JD5``#0]QL`^18``-`7``#0
M]Y8WD0$`0/GA-P#Y`0"`TB```-``N"B1`"@`D0(,0*GB#P2I`@Q!J>(/!:D`
M0$!YX,,`>0```-``>#:1I_W_EP```-``G#:1I/W_EP```-``O#:1H?W_EP``
M`-``X#:1GOW_EZ#^-I&<_?^7````T``\-Y&9_?^7P!(VD9?]_Y>`;C>1E?W_
ME^`#%ZJ3_?^7````T`"\-Y&0_?^7````T``T-I&-_?^7````T`#D-Y%X_?^7
M@```M.$#`*K@`Q>JJOW_EP```-``*#B1<?W_E^$#`*J```"T````T`!4-)&B
M_?^7````T`!P.)%I_?^7X0,`JJ`!`+3`$C:1F_W_EZ#^-I$!``#0(2`YD9?]
M_Y=SYD?YX3=`^6`"0/D@``#*0`(`M%W\_Y<```#0`+`XD5C]_Y?A`P"J8```
MM(!N-Y'O__\7]@,!D0$``-#`1@"1(?0XD4(!@-*T^_^7(/W_-<%N`)'V__\7
M\U-!J?5;0JGW&T#Y_7O'J,`#7];]>[ZI_0,`D?,+`/G3``"08`I`N1\$`#%!
M`0!4````T`!L-Y$\_?^70`$`M```0#D``0`T'\``<>`'GQI@"@"Y8`I`N?,+
M0/G]>\*HP`-?U@``@%+Z__\7_7N_J?T#`)$S_/^7OOO_ET```+0``$#Y_7O!
MJ,`#7];]>[VI_0,`D?5;`JD5``#0MBHYD?-3`:GS`P"JX`,6JA_]_Y>```"T
M`0!`.?0#`*KA```UX0,3JJ`J.9'S4T&I]5M"J?U[PZA+_?\7X0,3JI'[_Y>`
M`@"UX`,3J@[\_Y?U`P"JX`,4J@O\_Y>@`@"+``@`D6C[_Y?D`Q2J]0,`JN(#
M$ZH#``#0`0``T&-H-I$AM#F1\/O_E^$#%:K@`Q:JY___%_-30:GU6T*I_7O#
MJ,`#7]8,,I#2_V,LR^$C0)']>P"I_0,`D?=C`ZFW``#P&```T/5;`JGV`P"J
MX.9'^?-3`:GY:P2I^W,%J0(`0/DBQ`#Y`@"`TL```)``(`"1`HQ`J>(/!JD"
M#$*IX@\)J0(,0ZGB#PJI`@Q$J>(/"ZD"#$6IXH\'J0$,0/GA.P#Y`#!`^>!'
M`/D`$S:1V/S_E^`!`+0!`$`Y\P,`JH$!`#2L__^7X`,3JD?[_Y?S`P"J]^9'
M^>`C0)$!Q$#YX`)`^2```,J@)P"TR_O_EYG__Y?S`P"J``(`M?3C`9&``D#Y
M@```M1,``-!S:CF1"@``%+_\_Y=@``"UE"(`D?C__Q<!`$`YH?__-"_[_Y?S
M`P"J0/__M.`#$ZJS^_^7`/A_TQ4``-``!`"1M88YD0[[_Y?Z`P"J]`,`JF("
M0#F"!P`U]$,"D9,"0/F3`0"TX`,3JJ?\_Y?S`P"J8`<`M`$`0#DA!P`TI/W_
ME^`&`#3@`Q.J%?O_E_,#`*KU@P&1LP``M;0"0/ET``"T@`)`.0`&`#7@`Q.J
ME/O_E_D#`*K@`QJJD?O_ESD#``LY$Q`1%0``T#E_0)/@`QFJZ_K_E^4#&JJC
M<C:1X@,3J@0``+"$F#F1]`,`J@$``+`AK#F1<OO_E^`#%*H!.(!25_O_EQ\$
M`#'A`P!44/O_EP0`0+F?1`!Q8`,`5*```-`!``"PP@)`^>,#%*H`Q$?Y(=`Y
MD0``0/DI^_^7$P"`TJ+__Q?@`Q2JX0,5JG,&`)&4"@"16OO_E[[__Q>4(@"1
MO___%^`#%*II_?^7@```-.`#%*K:^O^7\P,`JK4B`)'%__\7X0,#D>`#%*K,
M^O^7^P,`*D`!`#2@``#0XP,4JL("0/D!``"P`,1'^2&\.I$``$#Y"OO_E^'_
M_Q?@TT"Y``P4$A\00'&!_O]4\]M`N5/[_Y=_`@!K`?[_5.#30+D`(``2'P`'
M<8']_U3@`QFJH_K_E_,#`*H```"P`%0YD4'\_Y=@"P"UV0)`^>`#&:H[^_^7
M^@,`JA\,`'&-`P!4`'Q`DP$``+``$`#1(0@\D2`#`(MV^O^7H`(`-5\3`''`
M``!46A,`43K#.HM`\U\X'[P`<<$!`%36!D#YE@$`M.`#%JHF^_^7'PP`\0D!
M`%0`$`#1`0``L,`"`(LA'#R18_K_EQ\``'$Y$Y::V?[_ER`-`#7@`QFJ`0"`
M4I3Z_Y?V`P`J@`P`-$(`@%(A`H"2^2,&D4[Z_Y?A`QFJX`,6*L(`@-+6^O^7
MX"-&.2`&`#7@)T8Y'PP!<<$%`%3@*T8Y'P0!<6$%`%3@+T8Y'PP!<0$%`%3@
M,T8Y'R`!<:$$`%3@-T8Y'Q0!<4$$`%1"`(!2(0>`DN`#%BHU^O^7X0,9JN`#
M%BHB!8#2O?K_EP4``+#D`QFJI0@_D0$``+"C<C:1X@,4JB$P/)'@`Q.JW/K_
ME^`#%*K&^O^7X0,3J@`3-I$?_/^7X`,3JL#^_Y<7__\7V0)`^5KZ_Y?A`P"J
MX`,9JG7]_Y?Y`P"J(/3_M9___Q<"`(!2`0"`TN`#%BH4^O^7MP4`E/H#`*H"
M`)#2X0,9JN`#%BJ:^O^7X@,`JA\``'$L`P!4X`,6*OEC!9&,^O^7_`,9JN$#
M&JH:``"P6H<YD18`@-+[`P61X`,;JA<&`)1B:W8XX`,9JN$#&JK6!@"1.0L`
MD:[Z_Y??4@#Q(?__5`4``+#D`QRJI0@_D?\#!CG&__\7X0,9JN`#&JJK!0"4
MWO__%P$``+`A(#F1&0``L#FG/)$```"P`&PWD>3[_Y>U<C:1ZOG_EQ8``+#6
M"C^1Y`,`*N4#%JKC`Q6JX@,4JN`#$ZH!``"P(6P\D9#Z_Y?@`Q.J`3B`4G7Z
M_Y<?!``Q`?;_5&[Z_Y<``$"Y'T0`<8'U_U36^?^7>P<`$>0#`"KF`Q:JY0,;
M*N,#%:KB`Q2JX0,9JN`#$ZI]^O^7[?__%^`#$ZH,,I#2_7M`J?-30:GU6T*I
M]V-#J?EK1*G[<T6I_V,LB\`#7];]>[JI_0,`D?-3`:FS``#0]5L"J77>1_GW
M8P.I^6L$J?MS!:F@`D"Y8_K_E_0#`*J@`D"Y8/K_EX'B0CD!Y`(Y````L`#\
M-I%Q^_^7P```M`$`0#D_Q`!Q80``5``$0#E````TN_W_EW;>1_FT``#PP`)`
MN5#Z_Y<!``"P8P&`4B'H/)$B`(!2Y_G_ER`$`+5VWD?YP`)`N4?Z_Y=C`(!2
M(@"`4@$``+`A_#R1WOG_E_4#`*H`"@"U=]Y'^>`"0+D]^O^78P"`4B(`@%(!
M``"P(7P]D=3Y_Y?U`P"J0`P`M````+``-#:12?O_E_8#`*I`"@"TX`)`N2_Z
M_Y>A"D#YX@,6JB$`0/G/^?^75@``%``(0/D;@(!2FL("D34`@%(;!*!R&!1`
M^;D&`%%!!T"YP`)`N3\`%6L-`0!4'OK_ER)_0)/A`QBJ`P"`4G[Y_Y?W`P"J
M0`$`M8#"`I$!!$"Y(00`43\`&6M!^?]4=]Y'^?4#`*HV`(!2&@``%`$`0/E`
M!T#Y'-AU^"`,0+D``!L*'P`0<>$``%0A"$#YX`,<JEWY_Y>@_?\UM08`$=__
M_Q?``D"Y`/K_E^$"0/E#`(!2`@"`T@SZ_Y?A`P"J]/__%]8&`!'X^?^7X0,8
MJB+Y_Y>A!D"YX`)`N3\`%FLL__]4J/__%\`"0+GO^?^7H0I`^0(``+!"!#V1
M(0!`^8[Y_Y>@"D#Y``!`^0`,0+G@]+<VP`)`N>3Y_Y>A"D#Y(0!`^4WY_Y>A
M__\7//S_E_8#`*K@`D"Y]@0`M-OY_Y>A"D#YX@,6JB$`0/E[^?^7X`,6JL7Y
M_Y=SWD?Y8`)`N=+Y_Y?U`P"J8`)`N<_Y_Y<B`(!2`0``L"$8/9$#^?^7`@``
ML.$#`*I";#V1X`,5JFKY_Y=@`D"YD\("D</Y_Y<?Y`(Y````L``0-I'5^O^7
M8`H`^<`!`+5@!D#YU_W_EV`*`/E``0"U````L`"$/9'^^/^7M?G_EX'"`I$B
M!$#YH0I`^4(`0/F$__\7E,("D0$X@%*`"D#YF/G_E^,#`"H?1`!Q(`$`5``$
M`!$?!`!QR0``5("*0*D!`$#Y````L``(/I'I^/^7\U-!J?5;0JGW8T.I^6M$
MJ?MS1:G]>\:HP`-?UOU[OJG]`P"1\U,!J?,#`*J[_/^7LOS_E_0#`*IC_?^7
MP`$`-+,!`+1@`D`Y8`$`-.`#%*H!``"P(9@YD1[Y_Y>?`@#KH0``5.`#$ZKS
M4T&I_7O"J$C[_Q?S4T&I_7O"J,`#7];_PPK1J```T`7@`)$'X`&1_7L`J?T#
M`)$!Y4?Y\PL`^2(`0/GB5P'Y`@"`TN*C`)'F`P*JH0!`N<9``)&DA$#X(0C`
M6L$`'_C_``7K@?Q@TR,<"%,AW'C3(1QPDF$``:J#_&C38QQXDF3@1*HA``2J
MP8`?^`'^_U0#"(!21"!`^6,$`'%!-$#Y0B``D46`7_@A``3*1`1`^80`!<HA
M``3*)/Q?TX$$`:HA?$"203P`^6'^_U0),$"I)C./T@HL0:E&4*OR#1!`^27]
M6].'_4+3I10)JN=X#*IA`0K*\'Q`DB$`#(H$`@K*(0`+RH0`"8HE0"6+A``*
MRN$70/F$``N+(OU"TR$`!HM">`FJI0`!B^,``LKA&T#YI0`-"V,`!8I.?$"2
M(0`&BV,`$,J$``&+H?Q;TR$4!:IC``J+CP`!BX0``0OA'T#Y(0`&BV,``8OA
M?7O3[WT;4R$`#ZIG``&+8P`!"Z'\0M,E>`6J00`%RJ]\0)+B(T#Y(0`$BB$`
M#LI"``:+(0`0BR$``HOB?'O3YWP;4T(`!ZHP``*+(0`""X+\0M-$>`2JH@`$
MRH=\0)+E)T#Y0@`#BD(`#\JE``:+0@`.BT(`!8L%?GO3$'X;4Z4`$*I0``6+
M0@`%"V7\0M.C>`.JA0`#RFY\0)+D*T#YI0`!BJ4`!\J$``:+I0`/BZ4`!(L$
M?GO3$'X;4X0`$*JP``2+I0`$"R3\0M.!>`&J9``!RB]\0)+C+T#YA``"BH0`
M#LIC``:+A``'BX0``XL#?GO3$'X;4V,`$*J0``.+A``#"T/\0M-B>`*J(P`"
MRD=\0)+A,T#Y8P`%BF,`#\HA``:+8P`.BV,``8L!?GO3$'X;4R$`$*IP``&+
M8P`!"Z'\0M,E>`6J00`%RJY\0)+B-T#Y(0`$BB$`!\I"``:+(0`/BR$``HL"
M?GO3$'X;4T(`$*HO``*+(0`""X+\0M-$>`2JH@`$RI!\0)+E.T#Y0@`#BD(`
M#LJE``:+0@`'B^=]>]/O?1M3YP`/JD(`!8M%``>+0@`'"V?\0M/C>`.JAP`#
MRF]\0)+D/T#YYP`!BN<`$,J$``:+YP`.B^<`!(ND?'O3I7P;4X0`!:KQ``2+
MYP`$"R3\0M.!>`&J)'Y[TV4``<HQ?AM3XT-`^:4``HJE``_*A``1JF,`!HNE
M`!"+I0`#BRY\0)*C``2+I0`$"T3\0M.">`*J)``"RE!\0)+A1T#YA``'BH0`
M#LHA``:+A``/BX0``8MA?'O38WP;4R$``ZJ1``&+A``!"^'\0M,G>`>J0P`'
MRN]\0)+A2T#Y8P`%BF,`$,HA``:+8P`.BV,``8LA?GO3,7X;4R$`$:IQ``&+
M8P`!"Z'\0M,E>`6JX@`%RJY\0)+A3T#Y0@`$BD(`#\HA``:+0@`0BT(``8LA
M?GO3,7X;4R$`$:I0``&+0@`!"X'\0M,D>`2JH0`$RH=\0)+E4T#Y(0`#BB$`
M#LJE``:+(0`/BR$`!8L%?GO3$'X;4Z4`$*HO``6+(0`%"V7\0M.C>`.J\7U[
MTX0``\IE?$"2A``"BN]]&U.$``?*,0(/JH0`#HON5T#YS@$&BX0`#HM._$+3
MPGD"JI``$8MC``+*3WQ`DF,``8H.?GO38P`%RA!^&U-C``>+S@$0JN=;0/F$
M`!$+YP`&BY'\0M-C``>+9P`.BV,`#@LN_$+3P7D!JD(``<HN?$"20@`$BB1Z
M!*I"``_*(0`$RD(`!8LA``.*Y5]`^2$`#LHA``^+I0`&BT(`!8OE?!M3YV@;
M4^<`!:IE_$+34``'BT(`!POG8T#YHW@#JH4``\KF``:+1_Q;T^<4`JHA``:+
MYF=`^2]`)XNE`!!*X0`!"R=TG=*E``Z+)]NM\L8`!XNF``:+)?Q;TZ44`:K.
M0"6+I0`&"T;\0M/">`*J<0`"RC$"#THQ0B2+Y&M`^80`!XLD`@2+L?Q;TS$6
M!:J00#&+,0($"R3\0M.!>`&JI/Q"TX5X!:I/``'*[P$.2BX`!<K.`1!*XT$C
MB\)!(HOONTVI[P$'B\X!!XMC``^++_Y;T^\5$:I"``Z+9D`OB^,!`PMN_%O3
M;_Q"T\X5`ZKO>0.J1$`NB\(!`@LN_D+3T7D1JD[\0M.P`!'*SGD"JA`"!DH!
M0B&+\'=`^1`"!XLA`!"+4/Q;TQ`6`JKB`0[*)D`PBQ`"`0LA`@_*0@`&2B$`
M!$I10#&+)4`EBP3^6]/A"T^IA!00JB$`!XM"``>+I0`!BP'^0M.C0"2+A0`%
M"S!X$*HQ`@*+LOQ;TZ'\0M-2%@6J)7@%JL8!$,H$`@7*(D(RB\8``TJ$``)*
MST`OBXY`+HM1`A$+YA-0J2+^0M/&``>+A``'B^\!!HLF_EO3QA01JE%X$:JC
M`!'*S@$$B_-!)HO&``\+8P`32L3\6]//_$+3A!0&JG!`,(OF>0:JXS]1J=Y!
M)(N$``X+(0(&RB$`'DHA0"6+COQ"TV,`!XOO`0>+$`(#BX/\6]-C%`2J(0`/
MB\1Y!*H30B.+8P`0"\(`!,IR_%O3</Q"TU(6`ZH#>@.JA0`#RD(`$THO0#*+
M00(!"Z4`#TI"0#&+ID`FBS'\6]/N%U*I,18!JB_\0M/A>0&JS@$'BZ4`!XM"
M``Z+;@`!RE-`,8LB`@(+S@$32L8`!8O$022+1?Q;T^Z;0/FE%`*JS@$'B]!`
M)8N$``Z+3OQ"T\)Y`JJE``8+)@`"RL8`$$JQ_%O3PT`CBS$6!:KFGT#YDT`Q
MBR0"!`O&``>+8P`&BZ;\0M/%>`6JD/Q;TT\`!<H0%@2J[P$32N]!(8N!_$+3
M(7@$JG)`,(OF$U2I`P(#"ZX``<IP_%O3S@$22A`6`ZK.02*+8OQ"T\8`!XM"
M>`.J[P$&BX0`!XOF03"+#P(/"\X!!(LC``+*Y/U;TV,`!DJ$%`^JYOU"T\]X
M#ZIE0"6+T4$DBT8`#\K&`!%*A``."\%`(8OC&U6ICOQ"TV,`!XO&``>+I0`#
MBX/\6]-C%`2JQ'D$JB$`!HNR0".+8P`%"^4!!,JE`!)*<?Q;TZ)`(HLQ%@.J
MY;-`^3``$8LA`!$+IP`'BV7\0M-"``>+!WY[TQ!^&U.C>`.JYP`0JF8`!`I.
M``>+0@`'"X<``ZJ%FY?2YP`!BF7CL?+G``:JYD`OB^>W0/GG``6+Q@`'B\=]
M>]/.?1M3YP`.JLX`!XO&``<+)_Q"T^%X`:IG``&J+P`#"N<``HKG``^JY$`D
MB^>[0/GG``6+A``'B\=]>]/.?1M3YP`.JHX`!XN$``<+1_Q"T^)X`JHG``*J
M3P`!"N<`!HKG``^JXT`CB^>_0/GG``6+8P`'B\=]>]/.?1M3YP`.JFX`!XMC
M``<+Q_Q"T^9X!JI'``:JSP`""N<`!(KG``^JX4`AB^?#0/GG``6+(0`'B\=]
M>]/.?1M3YP`.JBX`!XLA``<+A_Q"T^1X!*K'``2JCP`&"N<``XKG``^JXD`B
MB^?'0/GG``6+0@`'B\=]>]/.?1M3YP`.JDX`!XM"``<+9_Q"T^-X`ZJ'``.J
M;P`$"N<``8KG``^JYD`FB^?+0/GG``6+Q@`'B\=]>]/.?1M3YP`.JLX`!XO&
M``<+)_Q"T^%X`:IG``&J+P`#"N<``HKG``^JY$`DB^?/0/GG``6+A``'B\=]
M>]/.?1M3YP`.JHX`!XN$``<+1_Q"T^)X`JHG``*J3P`!"N<`!HKG``^JXT`C
MB^?30/GG``6+8P`'B\=]>]/.?1M3YP`.JFX`!XMC``<+Q_Q"T^9X!JI'``:J
MSP`""N<`!(KG``^JX4`AB^?70/GG``6+(0`'B\=]>]/.?1M3YP`.JBX`!XLA
M``<+A_Q"T^1X!*K'``2JCP`&"N<``XKG``^JXD`BB^?;0/GG``6+0@`'B\=]
M>]/.?1M3YP`.JDX`!XM"``<+9_Q"T^-X`ZJ'``.J;P`$"N<``8KG``^JYD`F
MB^??0/GG``6+Q@`'B\=]>]/.?1M3YP`.JLX`!XO&``<+)_Q"T^%X`:IG``&J
M+P`#"N<``HKG``^JY$`DB^?C0/GG``6+A``'B\=]>]/.?1M3YP`.JHX`!XN$
M``<+1_Q"T^)X`JHG``*J3P`!"N<`!HKG``^JXT`CB^?G0/GG``6+8P`'B\=]
M>]/.?1M3YP`.JFX`!XMC``<+Q_Q"T^9X!JI'``:JSP`""N<`!(KG``^JX4`A
MB^?K0/GG``6+(0`'B\=]>]/.?1M3YP`.JBX`!XLA``<+A_Q"T^1X!*K'``2J
MCP`&"N<``XKG``^JXD`BB^?O0/GG``6+0@`'B\=]>]/.?1M3YP`.JDX`!XM"
M``<+9_Q"T^-X`ZJ'``.J;P`$"N<``8KG``^JYD`FB^?S0/GG``6+Q@`'B\=]
M>]/.?1M3YP`.JLX`!XO&``<+)_Q"T^%X`:IG``&J+P`#"N<``HKG``^JY$`D
MB^?W0/GG``6+A``'B\=]>]/.?1M3YP`.JHX`!XN$``<+1_Q"T^)X`JK1?7O3
M)P`"JD\``0KG``:*SGT;4^<`#ZHQ`@ZJXT`CB^?[0/GG``6+8P`'BW``$8MQ
M`!$+P_Q"TV9X!JI'``:JPP`""N<`!(KG``.JX_]`^>%`(8MC``6+(0`#BP-^
M&U,0:AM3$`(#JH/\0M-D>`2J+@`0B\<`!*J#``8*YP`1BB$`$`OG``.J(_Y"
MT^)`(HMQ>!&JYP-!^2_\6]/O%0&J@P`1RN4`!8MC``Y*0@`%BV-`)HM'0"^+
MX@$""^8'0?DP_$+3$'H!JD[\6]/%.IC2(0(0RD5,N?+.%0*JQ@`%BR$`!TIC
M``:+)$`DBV9`+HM/_$+3S@$#"^]Y`JKA"T'Y`P(/RL?]6]-C``9*YQ0.JB$`
M!8OF#T'YA``!BY)`)XOG``0+Q@`%BW%`,8O#_4+3,0(&BVYX#JKF_%O3Y!-!
M^<84!ZKA`0[*(0`22C-")HN$``6+Q@`1"S!`,(L0`@2+Y/Q"TX=X!ZK2_%O3
M4A8&JL(!!\I"`!-*T?Q"TP%",HM/0"^+4`(0"R9Z!JKB%T'YXP`&RA+^6]-C
M``%*4A80JD(`!8OA&T'Y[P$"B^)!,HL$_D+33P(/"Y!X$*HA``6+;D`NB\X!
M`8O$`!#*X?U;TX0``DHA%`^JAT`GB^(?0?G102&+(0`."^/]0M-"``6+;W@/
MJN<``HLB_%O3`P(/RD(4`:IC`!%*+OQ"T_-`(HMF0":+0@`'"\%Y`:KC(T'Y
M4?Q;TS$6`JI'_$+38P`%B^)X`JK&``.+Y`$!RMY`,8LF`@8+[B=!^2,``LJ$
M`!-*8P`>2H1`,(O0_%O3$!8&JLX!!8MC0"^+S_Q"T^9Y!JJ$``Z+DD`PBTX`
M!LK.`1)*!`($"\%!(8ON+T'YD/Q;T^<K0?G.`06+$!8$JB$`#HOG``6+COQ"
MT\1Y!*IC``>+?D`PB\<`!,KG`!Y*`P(#"^)`(HOG,T'Y</Q;TQ`6`ZKG``6+
M0@`'BV?\0M/C>`.J,D`PBX\``\H!`@$+[P$22N]!)HLP_%O3YC=!^1`6`:H(
MY4?YQ@`%B^\!!HLF_$+3P7@!JE%`,(MN``'*`@(""\X!$4K.022+4/Q;T^0[
M0?D0%@*JA``%B_)!,(O.`02+1/Q"TX)X`JH/`@\+)P`"RN<`$DKP_5O3YT`C
MBQ`6#ZKC/T'YT4$PBPX"#@MC``6+YP`#B^/]0M-O>`^JT/U;TT8`#\H0%@ZJ
MQ@`12L9`(8OR0#"+X4-!^0<"!PLA``6+\/Q;T\8``8O!_4+3+G@.JA`6!ZKD
M`0[*A``22M%`,(N$0"*+!@(&"^)'0?GP_$+3!WH'JM#\0M-"``6+PP$'RH0`
M`HO"_%O30A0&JF,`$4IC0"^+!GH&JI)`(HM"``0+Y$M!^4_\6]/O%0*JX0`&
MRH0`!8LA`!)*8P`$BR%`+HMQ0"^+XP$#"^]/0?E$_$+3@G@"JBE!)XOO`06+
MS0`-"R$`#XMO_%O3[Q4#JDL`"PLA``^+#1``^2P`#`LN?!M3)'Q[TX0`#JK.
M``+*S@$12F'\0M.$``Z+(7@#JNY30?DJ``H+"BP!J<4!!8NE``F+A0`%"P4P
M`*GA5T'Y``%`^2```,I```"T*?7_E_U[0*GS"T#Y_\,*D<`#7];]>[^I`!"`
MTOT#`)%]]/^7'_P"J2)@A-*BZ*SR`@``^2)QE=(?>`"YHOF]\@($`/G"GYO2
M0A>S\@((`/G"CHK20@:B\@(,`/D"/IS20GJX\@(0`/G]>\&HP`-?UOU[O*G]
M`P"1\U,!J?,#`*I`?$"3]5L"J?0#`*IB%D#Y]QL`^4,,``M?``/KB0``5&(:
M0/E"!`"18AH`^6(:0/EUX@"10'1`BV."`JE@>D"Y@`,`-!8(@%+6`@!+GP(6
M:Z#"((N6TI8:'P`!Z\)^0).B``!4`P`"BS\``^M"``!4`'T@U#<``HL?``'K
M:0``5!\`%^MC__]4U_3_EV!Z0+G``@`+8'H`N1\``7'!`@!4X`,3JDC[_Y>4
M`A9+X0,7JG?B`9&?_@!QC`(`5()^0),_`!7KB0``5*`"`HL_``#K`_W_5#\`
M%>N"``!4(``"B[\"`.MC_/]4X`,5JK[T_Y=T>@"Y\U-!J?5;0JGW&T#Y_7O$
MJ,`#7]8_`!7K:0``5#\`%^OC^O]4/P`5ZS8``9%B``!4OP(6ZT/Z_U0B#$"I
MH@X`J90"`5$B#$&IH@X!J2(,0JFB#@*I(`1#J:`&`ZG@`Q.J'/O_E^$#%JK6
M__\7_7N\J?T#`)'S4P&I]`,`JO,#`:KU6P*I->``D?<;`/D@%$#Y-BA`N3<P
M0+GA#X`2`"`#4]8*P%H"!``1]PK`6E_@`'&ARB`XH,(BBXT)`%0!"(!2(@`"
M2P$`@%)"?$"3Z?/_E^`#$ZK_^O^7?_X#J7_^!*E__@6I?S8`^7=:#BG@`Q.J
M^/K_EV`"0/D`_%C3@`(`.6`"0/D`_%#3@`8`.6`"0/D`_$C3@`H`.6`"0/F`
M#@`Y8`9`^0#\6-.`$@`Y8`9`^0#\4-.`%@`Y8`9`^0#\2-.`&@`Y8`9`^8`>
M`#E@"D#Y`/Q8TX`B`#E@"D#Y`/Q0TX`F`#E@"D#Y`/Q(TX`J`#E@"D#Y@"X`
M.6`.0/D`_%C3@#(`.6`.0/D`_%#3@#8`.6`.0/D`_$C3@#H`.6`.0/F`/@`Y
M8!)`^0#\6-.`0@`Y8!)`^?5;0JD`_%#3@$8`.6`20/D`_$C3@$H`.6`20/F`
M3@`YX`,3JO-30:GW&T#Y_7O$J"OT_Q<!!X!2(@`"2P$`@%)"?$"3GO/_E[O_
M_Q?]>[^I_0,`D?U[P:C``U_6+W1M<`!005)?5$U01$E2`%1%35!$25(`5$U0
M`%5315(`55-%4DY!344`+BX`)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA
M3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`&5X90`O<')O8R\E:2\E<P!0
M05)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$52
M3#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?
M0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'`%!!
M4E]'3$]"04Q?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,
M14%.`%!!4E]#3$5!3CT`,0!,1%],24)205)97U!!5$@`4UE35$5-`"4P,G@`
M<&%R+0`E<R5S)7,E<P`E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`"5S.B!P<FEV871E('-U8F1I
M<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E
M=')Y('EO=7(@;W!E<F%T:6]N*0H`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S
M`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;`!0
M05(Z.E!A8VME<CHZ5D524TE/3@`Q+C`U,`!5;F%B;&4@=&\@8W)E871E(&-A
M8VAE(&1I<F5C=&]R>0`E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`"UE`"TM`&5V86P@
M)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C
M(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P
M;#L*;7D@*"1005)?34%'24,L("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP
M9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&
M:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I
M;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M
M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R
M7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@
M/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E
M;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM
M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A8
M6"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*
M4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@
M(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M
M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N
M"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B
M("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I
M;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU
M;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q
M*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU
M<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA
M;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"
M3T]4.PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I
M;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E
M0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@
M)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN
M?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@
M*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P
M<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D
M9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO
M<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I
M.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&-H=6YK
M7W-I>F4@/2`V-"`J(#$P,C0["FUY("1M86=I8U]P;W,["FEF("@D<VEZ92`\
M/2`D8VAU;FM?<VEZ92D@>PHD;6%G:6-?<&]S(#T@,#L*?2!E;'-I9B`H*&UY
M("1M(#T@)'-I>F4@)2`D8VAU;FM?<VEZ92D@/B`P*2!["B1M86=I8U]P;W,@
M/2`D<VEZ92`M("1M.PI](&5L<V4@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D
M8VAU;FM?<VEZ93L*?0IW:&EL92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96LH
M7T9(+"`D;6%G:6-?<&]S+"`P*3L*<F5A9"A?1D@L("1B=68L("1C:'5N:U]S
M:7IE("L@;&5N9W1H*"1005)?34%'24,I*3L*:68@*"AM>2`D:2`](')I;F1E
M>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I
M.PIL87-T.PI]"B1M86=I8U]P;W,@+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I
M9B`D;6%G:6-?<&]S(#P@,#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P
M.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T
M("T@=6YP86-K*").(BP@)&)U9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(
M.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@
M("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW
M:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E
M860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE
M(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN
M+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI
M+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D
M8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F
M+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD
M969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O
M:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U
M9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]
M("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65]
M(#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL
M:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N
M86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D[
M"F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER
M95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[
M)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE
M(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A
M;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T
M=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`](&1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5](&]R(')E='5R;CL*)$E.0WLD
M;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM0
M05)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E
M*"1F:"D["G!R:6YT("1F:"`D:6YF;RT^>V)U9GT["G-E96LH)&9H+"`P+"`P
M*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F
M:6QE*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY
M("1F:"P@)SPG+"`D9FEL96YA;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE
M;F%M93H@)"$B.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")"
M;V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B([
M"GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A
M=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@
M24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R
M97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R
M("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<
M+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F
M:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP
M;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL
M87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]
M("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II
M<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@
M)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S
M86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U
M:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P
M;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI
M('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS
M=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V
M97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U
M<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI
M9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY
M($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM
M*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=)
M)RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG
M*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H
M:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T
M(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G
M.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L
M<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@
M)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N
M;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C
M:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D
M9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET
M7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F
M;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC
M.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R
M(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2![
M"F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G
M)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL
M92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E
M;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E
M;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD
M;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N
M*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I
M('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN
M;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S
M<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`[
M"FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-2
M14%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U12
M54Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@
M*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E
M:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A
M)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R
M96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A
M8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[
M)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>
M6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@
M(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*
M)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@
M)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^
M<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E
M<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`]
M(&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G
M*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD
M7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY
M("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA
M<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF
M:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O
M<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@
M;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<
M421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H
M)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;
M7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE
M0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S
M=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@
M*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I
M;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@
M(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO
M=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL
M92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII
M9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE
M;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E
M;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%
M/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<
M)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%
M4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z
M.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@
M)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI
M.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE
M;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O
M)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N
M86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I
M*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I
M;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D
M8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M
M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI3
M2$$M/FYE=R@Q*3L*;W!E;BAM>2`D9F@L("(\(BP@)&]U="D["F)I;FUO9&4H
M)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8V%C:&5?
M;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B
M('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@
M(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H
M<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M
M/G!R:6YT*"1005)?34%'24,I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D
M;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S
M.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E
M<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(
M*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["D%R8VAI=F4Z.EII<#HZ<V5T0VAU
M;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*
M)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E
M.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI
M8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II
M<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM0
M05)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD969I;F5D("1%
M3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT
M(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT
M(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D
M;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^
M(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX
M.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE
M.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE
M*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O
M;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N
M86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I
M*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B
M('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M
M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>
M3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD
M<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@
M)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C
M+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE
M72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@
M)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA
M;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA
M;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H
M)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0
M871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H
M(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U
M:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97([
M"G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A
M<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP
M;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O
M;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E
M;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T[
M"F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA
M<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R
M<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@
M?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A
M;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?
M=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!
M4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*
M?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]4
M35!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-
M4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@
M+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I
M9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D
M/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E
M<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D
M<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA
M;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG
M.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A
M=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE
M*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y]
M(&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N
M("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*
M<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%
M(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$[
M"B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I[
M"G)E<75I<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^
M;F5W*#$I.PIO<&5N*&UY("1F:"P@(CPB+"`D<')O9VYA;64I.PIB:6YM;V1E
M*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^
M:&5X9&EG97-T.PI]('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92![
M"B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I
M9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO
M9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU
M;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN
M86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B
M8V%N)W0@=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN
M="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M
M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U
M;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN
M86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM0
M05)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO
M*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D
M14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]4
M14U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R
M:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@
M*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N
M9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P
M<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N
M86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X
M97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O
M;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES
M=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T[
M"B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M
M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE
M?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@
M/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X
M*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE
M(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H
M9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F
M:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D
M8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#
M;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV
M('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U
M<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R
M("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%
M("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U0
M1$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D
M14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/
M0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.
M7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L
M971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!
M4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L
M96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]
M("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@
M;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@
M)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B
M(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D
M969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E
M>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R
M8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E
M(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP
M;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R
M;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O
M<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%
M.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID
M:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%
M.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$
M7U\*`'!E<FQX<VDN8P!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M(``````!&P,[\````!T```#TD___+`4```R6__\(`0``/);__QP!``!XEO__
M,`$``."6__]4`0``$)?__W0!``#,E___J`$``!28___,`0``I)C___@!``"$
MFO__-`(``-2;__]P`@``7)S__Y@"``"4G/__N`(``.B<___<`@``&)[__Q`#
M```<GO__)`,``.R?__]P`P``#*#__X0#```0H?__P`,``+BB___P`P``$*/_
M_Q0$```PH___-`0``.2C__]L!```P*G__[P$```0K?___`0``'2M__]<!0``
M1+___X0%``"@O___I`4``!#!___8!0``$``````````!>E(`!'@>`1L,'P`0
M````&````/R4__\P`````````!`````L````&)7__SP`````````(````$``
M``!`E?__:`````!$#B"=!)X#0I,"4M[=TPX`````'````&0```"$E?__,```
M``!$#A"=`IX!1][=#@`````P````A````)25__^\`````$$.0)T(G@=$DP:4
M!94$E@.7`I@!8PK>W=?8U=;3U`X`00L`(````+@````<EO__2`````!!#C"=
M!IX%0I,$3M[=TPX`````*````-P```!`EO__D`````!!#D"=")X'0Y,&E`5$
ME026`UO>W=76T]0.```X````"`$``*26___@`0```$$.8)T,G@M"E0B6!T23
M"I0)0Y<&F`69!)H#`FW>W=G:U]C5UM/4#@`````X````1`$``$B8__]0`0``
M`$$.X`&=')X;0I48EA=%DQJ4&9<6F!69%)H3`DO>W=G:U]C5UM/4#@`````D
M````@`$``%R9__^(`````$$.L`&=%IX50I,4E!->WMW3U`X`````'````*@!
M``"\F?__.`````!!#A"=`IX!1M[=#@`````@````R`$``-29__]4`````$$.
M()T$G@-"DP)*WMW3#@`````P````[`$```2:__\P`0```$(.T$!!G8H(GHD(
M0I6&"):%"$.3B`B4AP@"0]W>U=;3U`X`$````"`"````F___!`````````!(
M````-`(``/":___0`0```$(.\"%!G9X$GIT$0I6:!):9!$*3G`24FP1&EY@$
MF)<$F98$FI4$FY0$`F;=WMO9VM?8U=;3U`X`````$````(`"``!TG/__(```
M```````X````E`(``("<__\$`0```$(.()T$G@-"DP)'WMW3#@!!#B"3`IT$
MG@-O"M[=TPX`00M"#@#3W=X````L````T`(``$B=__^H`0```$$.<)T.G@U"
MDPR4"T25"I8)0I<(`F#>W=?5UM/4#@`@``````,``,">__]8`````$$.()T$
MG@-"DP)0"M[=TPX`00L<````)`,``/2>__\@`````$$.$)T"G@%&WMT.````
M`#0```!$`P``])[__[0`````00XPG0:>!4*5`I8!0Y,$E`-,"M[=U=;3U`X`
M00M9WMW5UM/4#@``3````'P#``!PG___W`4```!"#I"#`D*=LB">L2!"EZP@
MF*L@0Y6N():M($63L""4KR"9JB":J2";J""<IR`#:`'=WMO<V=K7V-76T]0.
M```\````S`,``/RD__]0`P```$$.8)T,G@M"DPJ4"4*5")8'1)<&F`69!)H#
MFP*<`0+*WMW;W-G:U]C5UM/4#@``+`````P$```,J/__9`````!!#B"=!)X#
M0I,"E`%2"M[=T]0.`$$+0M[=T]0.````+````#P$``#`CO__U`$```!!#E"=
M"IX)0I,(E`=#E08":0K>W=73U`X`00L`````)````&P$```0J/__T!$```!!
M#K`%1)U6GE5#DU0#:P3=WM,.`````!P```"4!```N+G__UP`````00X0G0*>
M`57>W0X`````,````+0$``#TN?__<`$```!!#D"=")X'0I,&E`5&E026`Y<"
M?`K>W=?5UM/4#@!!"P```#````#H!```,+O__Y0!````00Y`G0B>!T*3!I0%
M0Y4$E@-"EP("5@K>W=?5UM/4#@!!"P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#PA````````U"`````````!
M``````````$``````````0````````#9`@````````\`````````@00`````
M```,`````````#@:````````#0``````````30```````!D`````````@)L!
M```````;``````````@`````````&@````````"(FP$``````!P`````````
M"`````````#U_O]O`````"`"````````!0`````````0#0````````8`````
M````"`,````````*`````````)\$````````"P`````````8`````````!4`
M```````````````````#`````````'"=`0```````@````````#0!0``````
M`!0`````````!P`````````7`````````&@4````````!P````````"P$0``
M``````@`````````N`(````````)`````````!@`````````&```````````
M`````````/O__V\``````0``"`````#Y__]O`````!``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!0&@```````%`:````````4!H```````!0&@```````%`:````
M````4!H```````!0&@```````%`:````````4!H```````!0&@```````%`:
M````````4!H```````!0&@```````%`:````````4!H```````!0&@``````
M`%`:````````4!H```````!0&@```````%`:````````4!H```````!0&@``
M`````%`:````````4!H```````!0&@```````%`:````````4!H```````!0
M&@```````%`:````````4!H```````!0&@```````%`:````````4!H`````
M``!0&@```````%`:````````4!H```````!0&@```````%`:````````4!H`
M``````!0&@```````%`:````````4!H```````!0&@```````%`:````````
M4!H```````!0&@```````%`:````````4!H```````!0&@```````%`:````
M````4!H```````!0&@```````%`:````````4!H```````!0&@```````%`:
M````````4!H```````!0&@```````%`:````````4!H```````!0&@``````
M`%`:````````D)L!``````!0'@``````````````````````````````30``
M```````````````````````````X&@``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"@`0``````_____P`````030```````#M-````````````
M```````530```````!5.````````($T````````G3@```````"A-````````
M```````````L30```````#%-``````````````````#)3P```````$=#0SH@
M*$%L<&EN92`Y+C,N,"D@.2XS+C```"YS:'-T<G1A8@`N:6YT97)P`"YG;G4N
M:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI
M=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE
M`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`
M+F)S<P`N8V]M;65N=```````````````````````````````````````````
M``````````````````````````````````````````````L````!`````@``
M`````````@`````````"````````&@````````````````````$`````````
M```````````3````]O__;P(`````````(`(````````@`@```````.@`````
M`````P`````````(````````````````````'0````L````"``````````@#
M````````"`,````````("@````````0````#````"``````````8````````
M`"4````#`````@`````````0#0```````!`-````````GP0`````````````
M``````$````````````````````M````!`````(`````````L!$```````"P
M$0```````+@"`````````P`````````(`````````!@`````````-P````0`
M``!"`````````&@4````````:!0```````#0!0````````,````1````"```
M```````8`````````$$````!````!@`````````X&@```````#@:````````
M$`````````````````````0````````````````````\`````0````8`````
M````4!H```````!0&@`````````$```````````````````0`````````!``
M````````1P````$````&`````````%`>````````4!X```````"P+@``````
M````````````!````````````````````$T````!````!@``````````30``
M``````!-````````$`````````````````````0```````````````````!3
M`````0````(`````````$$T````````030```````$H]````````````````
M```!````````````````````6P````$````"`````````%R*````````7(H`
M``````#T````````````````````!````````````````````&D````!````
M`@````````!0BP```````%"+````````'`4```````````````````@`````
M``````````````!S````#@````,`````````@)L!``````"`FP````````@`
M```````````````````(``````````@`````````?P````\````#````````
M`(B;`0``````B)L````````(````````````````````"``````````(````
M`````(L````&`````P````````"0FP$``````)";````````X`$````````$
M``````````@`````````$`````````"4`````0````,`````````<)T!````
M``!PG0```````)`"```````````````````(``````````@`````````F0``
M``$````#``````````"@`0```````*````````!X````````````````````
M"````````````````````)\````(`````P````````!XH`$``````'B@````
M````6!````````````````````@```````````````````"D`````0```#``
M``````````````````!XH````````!H````````````````````!````````
M``$``````````0````,`````````````````````````DJ````````"M````
<`````````````````0``````````````````````
